@@ -5,9 +5,11 @@ import (
 	"errors"
 	"fmt"
 	"io"
+	"io/fs"
 	gohttp "net/http"
 	"os"
 	"strings"
+	"time"
 
 	"github.com/majd/ipatool/v2/pkg/http"
 	"github.com/majd/ipatool/v2/pkg/keychain"
@@ -19,6 +21,15 @@ import (
 	"howett.net/plist"
 )
 
+type dummyFileInfo struct{}
+
+func (d *dummyFileInfo) Name() string       { return "dummy" }
+func (d *dummyFileInfo) Size() int64        { return 0 }
+func (d *dummyFileInfo) Mode() fs.FileMode  { return 0 }
+func (d *dummyFileInfo) ModTime() time.Time { return time.Time{} }
+func (d *dummyFileInfo) IsDir() bool        { return false }
+func (d *dummyFileInfo) Sys() interface{}   { return nil }
+
 var _ = Describe("AppStore (Download)", func() {
 	var (
 		ctrl               *gomock.Controller
@@ -86,6 +97,36 @@ var _ = Describe("AppStore (Download)", func() {
 		})
 	})
 
+	When("request uses a custom pod", func() {
+		const (
+			testPod  = "42"
+			testGUID = "001122334455"
+		)
+
+		BeforeEach(func() {
+			mockMachine.EXPECT().
+				MacAddress().
+				Return("00:11:22:33:44:55", nil)
+
+			mockDownloadClient.EXPECT().
+				Send(gomock.Any()).
+				Do(func(req http.Request) {
+					expectedURL := "https://p" + testPod + "-" + PrivateAppStoreAPIDomain + PrivateAppStoreAPIPathDownload + "?guid=" + testGUID
+					Expect(req.URL).To(Equal(expectedURL))
+				}).
+				Return(http.Result[downloadResult]{}, errors.New(""))
+		})
+
+		It("sends the download request to the pod-specific host", func() {
+			_, err := as.Download(DownloadInput{
+				Account: Account{
+					Pod: testPod,
+				},
+			})
+			Expect(err).To(HaveOccurred())
+		})
+	})
+
 	When("password token is expired", func() {
 		BeforeEach(func() {
 			mockMachine.EXPECT().
@@ -221,6 +262,7 @@ var _ = Describe("AppStore (Download)", func() {
 
 	When("fails to download file", func() {
 		BeforeEach(func() {
+
 			mockOS.EXPECT().
 				Getwd().
 				Return("", nil)
@@ -251,14 +293,14 @@ var _ = Describe("AppStore (Download)", func() {
 			})
 		})
 
-		When("request fails", func() {
+		When("fails to open file", func() {
 			BeforeEach(func() {
 				mockHTTPClient.EXPECT().
 					NewRequest("GET", gomock.Any(), nil).
 					Return(nil, nil)
 
-				mockHTTPClient.EXPECT().
-					Do(gomock.Any()).
+				mockOS.EXPECT().
+					OpenFile(gomock.Any(), gomock.Any(), gomock.Any()).
 					Return(nil, errors.New(""))
 			})
 
@@ -268,21 +310,45 @@ var _ = Describe("AppStore (Download)", func() {
 			})
 		})
 
-		When("fails to open file", func() {
+		When("fails to get file info", func() {
 			BeforeEach(func() {
 				mockHTTPClient.EXPECT().
 					NewRequest("GET", gomock.Any(), nil).
 					Return(nil, nil)
 
+				mockOS.EXPECT().
+					OpenFile(gomock.Any(), gomock.Any(), gomock.Any()).
+					Return(nil, nil)
+
+				mockOS.EXPECT().
+					Stat(gomock.Any()).
+					Return(&dummyFileInfo{}, errors.New(""))
+
+			})
+
+			It("returns error", func() {
+				_, err := as.Download(DownloadInput{})
+				Expect(err).To(HaveOccurred())
+			})
+		})
+
+		When("request fails", func() {
+			BeforeEach(func() {
 				mockHTTPClient.EXPECT().
-					Do(gomock.Any()).
-					Return(&gohttp.Response{
-						Body: gohttp.NoBody,
-					}, nil)
+					NewRequest("GET", gomock.Any(), nil).
+					Return(&gohttp.Request{Header: map[string][]string{}}, nil)
 
 				mockOS.EXPECT().
 					OpenFile(gomock.Any(), gomock.Any(), gomock.Any()).
-					Return(nil, errors.New(""))
+					Return(nil, nil)
+
+				mockOS.EXPECT().
+					Stat(gomock.Any()).
+					Return(&dummyFileInfo{}, nil)
+
+				mockHTTPClient.EXPECT().
+					Do(gomock.Any()).
+					Return(&gohttp.Response{Body: io.NopCloser(strings.NewReader(""))}, errors.New(""))
 			})
 
 			It("returns error", func() {
@@ -295,17 +361,22 @@ var _ = Describe("AppStore (Download)", func() {
 			BeforeEach(func() {
 				mockHTTPClient.EXPECT().
 					NewRequest("GET", gomock.Any(), nil).
+					Return(&gohttp.Request{Header: map[string][]string{}}, nil)
+
+				mockOS.EXPECT().
+					OpenFile(gomock.Any(), gomock.Any(), gomock.Any()).
 					Return(nil, nil)
 
+				mockOS.EXPECT().
+					Stat(gomock.Any()).
+					Return(&dummyFileInfo{}, nil)
+
 				mockHTTPClient.EXPECT().
 					Do(gomock.Any()).
 					Return(&gohttp.Response{
 						Body: io.NopCloser(strings.NewReader("ping")),
 					}, nil)
 
-				mockOS.EXPECT().
-					OpenFile(gomock.Any(), gomock.Any(), gomock.Any()).
-					Return(nil, nil)
 			})
 
 			It("returns error", func() {
@@ -313,6 +384,7 @@ var _ = Describe("AppStore (Download)", func() {
 				Expect(err).To(HaveOccurred())
 			})
 		})
+
 	})
 
 	When("successfully downloads file", func() {
@@ -347,13 +419,17 @@ var _ = Describe("AppStore (Download)", func() {
 					},
 				}, nil)
 
+			mockHTTPClient.EXPECT().
+				NewRequest("GET", gomock.Any(), nil).
+				Return(&gohttp.Request{Header: map[string][]string{}}, nil)
+
 			mockOS.EXPECT().
 				OpenFile(gomock.Any(), gomock.Any(), gomock.Any()).
 				Return(testFile, nil)
 
-			mockHTTPClient.EXPECT().
-				NewRequest("GET", gomock.Any(), nil).
-				Return(nil, nil)
+			mockOS.EXPECT().
+				Stat(gomock.Any()).
+				Return(&dummyFileInfo{}, nil)
 
 			mockHTTPClient.EXPECT().
 				Do(gomock.Any()).
@@ -387,6 +463,7 @@ var _ = Describe("AppStore (Download)", func() {
 			)
 
 			BeforeEach(func() {
+
 				var err error
 				tmpFile, err = os.OpenFile(fmt.Sprintf("%s.tmp", testFile.Name()), os.O_CREATE|os.O_WRONLY, 0644)
 				Expect(err).ToNot(HaveOccurred())
