@@ -14,14 +14,15 @@ const (
 	iTunesAPIPathSearch = "/search"
 	iTunesAPIPathLookup = "/lookup"
 
-	PrivateAppStoreAPIDomainPrefixWithoutAuthCode = "p25"
-	PrivateAppStoreAPIDomainPrefixWithAuthCode    = "p71"
-	PrivateAppStoreAPIDomain                      = "buy." + iTunesAPIDomain
-	PrivateAppStoreAPIPathAuthenticate            = "/WebObjects/MZFinance.woa/wa/authenticate"
-	PrivateAppStoreAPIPathPurchase                = "/WebObjects/MZFinance.woa/wa/buyProduct"
-	PrivateAppStoreAPIPathDownload                = "/WebObjects/MZFinance.woa/wa/volumeStoreDownloadProduct"
+	PrivateInitDomain = "init." + iTunesAPIDomain
+	PrivateInitPath   = "/bag.xml"
+
+	PrivateAppStoreAPIDomain       = "buy." + iTunesAPIDomain
+	PrivateAppStoreAPIPathPurchase = "/WebObjects/MZFinance.woa/wa/buyProduct"
+	PrivateAppStoreAPIPathDownload = "/WebObjects/MZFinance.woa/wa/volumeStoreDownloadProduct"
 
 	HTTPHeaderStoreFront = "X-Set-Apple-Store-Front"
+	HTTPHeaderPod        = "pod"
 
 	PricingParameterAppStore    = "STDQ"
 	PricingParameterAppleArcade = "GAME"
